# PRADO

The PyTorch implementation of the architecture described in [PRADO - Projection Attention Networks for Document Classification On-Device](https://www.aclweb.org/anthology/D19-1506.pdf) by Kaliamoorthi et al., 2019.
